@@ -7,10 +7,8 @@
 #include <QPainter>
 #include <QPainterPath>
 #include <QResizeEvent>
-#include <QX11Info>
 
 #include <X11/extensions/shape.h>
-#include <X11/Xregion.h>
 
 MonitorIndicator::MonitorIndicator(QWidget *parent)
     : QFrame(parent)
@@ -24,6 +22,12 @@ void MonitorIndicator::resizeEvent(QResizeEvent *e)
 {
     QFrame::resizeEvent(e);
 
+    Display* display = XOpenDisplay(nullptr);
+    if (!display) {
+        qWarning() << "XOpenDisplay failed";
+        return;
+    }
+
     XRectangle rectangle;
     rectangle.x = 0;
     rectangle.y = 0;
@@ -31,12 +35,12 @@ void MonitorIndicator::resizeEvent(QResizeEvent *e)
     rectangle.height = static_cast<ushort>(e->size().height());
 
     // need to restore the cut area, if not,cut out will be repeated.
-    XShapeCombineRectangles(QX11Info::display(), winId(), ShapeBounding, 0, 0, &rectangle, 1, ShapeSet, YXBanded);
+    XShapeCombineRectangles(display, winId(), ShapeBounding, 0, 0, &rectangle, 1, ShapeSet, YXBanded);
 
     rectangle.x = 10;
     rectangle.y = 10;
     rectangle.width = static_cast<ushort>(e->size().width()) - 20;
     rectangle.height = static_cast<ushort>(e->size().height()) - 20;
 
-    XShapeCombineRectangles(QX11Info::display(), winId(), ShapeBounding, 0, 0, &rectangle, 1, ShapeSubtract, YXBanded);
+    XShapeCombineRectangles(display, winId(), ShapeBounding, 0, 0, &rectangle, 1, ShapeSubtract, YXBanded);
 }
